/* ISC license. */

#ifndef SHIBARI_H
#define SHIBARI_H

#include <shibari/common.h>
#include <shibari/server.h>

#endif
